probnum.quad
============

Quadrature / Numerical Integration of Functions.

This package implements Bayesian quadrature rules used for numerical
integration of functions on a given domain. Such methods integrate a function by
iteratively building a probabilistic model and adaptively choosing points to evaluate
the integrand based on said model.

.. automodapi:: probnum.quad
    :no-heading:
    :no-main-docstr:
